@@ -2,7 +2,7 @@
  * Programmer(s): Cody J. Balos, Aaron Collier and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -44,12 +44,12 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "7.2.1"
+#define SUNDIALS_VERSION "7.3.0"
 #define SUNDIALS_VERSION_MAJOR 7
-#define SUNDIALS_VERSION_MINOR 2
-#define SUNDIALS_VERSION_PATCH 1
+#define SUNDIALS_VERSION_MINOR 3
+#define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
-#define SUNDIALS_GIT_VERSION "v7.2.1"
+#define SUNDIALS_GIT_VERSION "v7.3.0"
 
 
 /* ------------------------------------------------------------------
@@ -84,6 +84,11 @@
  */
 #define SUNDIALS_INDEX_TYPE int64_t
 
+/* Define the type used for 'suncountertype'.
+ * The macro will be defined with a type of the appropriate size.
+ */
+#define SUNDIALS_COUNTER_TYPE long int
+
 /* Use POSIX timers if available.
  *     #define SUNDIALS_HAVE_POSIX_TIMERS
  */
@@ -106,7 +111,7 @@
 
 /* Build metadata */
 #define SUN_C_COMPILER "GNU"
-#define SUN_C_COMPILER_VERSION "14.1.1"
+#define SUN_C_COMPILER_VERSION "14.2.1"
 #define SUN_C_COMPILER_FLAGS "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection"
 
 #define SUN_CXX_COMPILER ""
@@ -119,8 +124,8 @@
 
 #define SUN_BUILD_TYPE "RelWithDebInfo"
 
-#define SUN_JOB_ID "20241220130304"
-#define SUN_JOB_START_TIME "20241220130304"
+#define SUN_JOB_ID "20250407142534"
+#define SUN_JOB_START_TIME "20250407142534"
 
 #define SUN_TPL_LIST "MPI;OPENMP;KLU;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
